#!/bin/csh -f
### ====================================================================
###  @UNIX-shell-file{
###     author          = "Van Jacobsen and Nelson H. F. Beebe",
###     version         = "2.00",
###     date            = "14 March 1995",
###     time            = "10:54:11 MST",
###     filename        = "tgrind.sh",
###     address         = "Lawrence Berkeley Laboratory
###			   Berkeley, CA
###			   USA
###
###			   and
###
###			   Center for Scientific Computing
###                        Department of Mathematics
###                        University of Utah
###                        Salt Lake City, UT 84112
###                        USA",
###     telephone       = "+1 801 581 5254",
###     FAX             = "+1 801 581 4148",
###     checksum        = "26264 208 686 5258",
###     email           = "beebe@math.utah.edu (Internet)",
###     codetable       = "ISO/ASCII",
###     keywords        = "program listings, shell script, TeX, tgrind,
###     		   typesetting, vgrind",
###     supported       = "yes (by NHFB)",
###     docstring       = "This is a UNIX C-shell script to produce
###			   nice program listings using TeX.
###
###			   This script was originally written in
###			   February 1985 by Van Jacobsen, based on the
###			   4.2BSD UNIX vgrind script.
###
###			   This script has been substantially revised
###			   by Nelson H. F. Beebe for release 2.0 of
###			   tgrind, which contains support for new
###			   languages, new keywords in vgrindefs, and
###			   multi-column procedure name indexing.
###
###			   The checksum field above contains a CRC-16
###                        checksum as the first value, followed by the
###                        equivalent of the standard UNIX wc (word
###                        count) utility output of lines, words, and
###                        characters.  This is produced by Robert
###                        Solovay's checksum utility.",
###  }
### ====================================================================
########################################################################
# CHANGE THIS VALUE IF YOU UPDATE TGRIND, AND NOTIFY THE AUTHORS
# LISTED ABOVE AND IN THE MAN PAGE FILE, tgrind.man:
set version="tgrind version 2.00 [14-Mar-1995]"
########################################################################
#
set b=/usr/local/bin/tfontedpr
set lib=/usr/local/lib/tex/inputs
set tex=/usr/local/bin/tex
set options=
# If your system doesn't have nawk, try gawk, or awk
set nawk=nawk
set basename=/tmp/$$
set texoptions=
set files=
set head=""
set fontname=""
set format=""
set print=""
top:
if ($#argv > 0) then
    switch ($1:q)

    case -d:
	if ($#argv < 2) then
	    echo "tgrind: $1:q option must have argument"
	    exit 1
	else
	    set options = ($options $1:q $2)
	    shift
	    shift
	    goto top
	endif

    case -f:
	set format="Y"
	shift
	goto top

    case -fn:
	if ($#argv < 2) then
	    echo "tgrind: $1:q option must have argument"
	    exit 1
	else
	    set fontname="$2"
	    shift
	    shift
	    goto top
	endif

    case -h:
	if ($#argv < 2) then
	    echo "tgrind: $1:q option must have argument"
	    exit 1
	else
	    set head="$2"
	    shift
	    shift
	    goto top
	endif

    case -l:			# reduce -l <language> to -l<language>
	if ($#argv < 2) then
	    echo "tgrind: $1:q option must have argument"
	    exit 1
	else
	    set options="$options $1:q$2"
	    shift
	    shift
	    goto top
	endif

    case -o:
	if ($#argv < 2) then
	    echo "tgrind: $1:q option must have argument"
	    exit 1
	else
	    set basename="$2"
	    shift
	    shift
	    goto top
	endif

    case -p:
	set print="Y"
	shift
	goto top

    case -*:
	set options = "$options $1:q"
	shift
	goto top

    default:
	set files = "$files $1:q"
	shift
	goto top
    endsw
endif

if (	-e $basename.tex || \
	-e $basename.log || \
	-e $basename.tmp || \
	-e $basename.dvi || \
	-e $basename.ps \
   ) then
	echo "Output file(s) already exist in $basename.* ...terminating"
	exit 1
endif

echo "%% $version for files $files on `date`" >$basename.tex

if ("$fontname" != "") echo "\def \FontName {"$fontname"}" >>$basename.tex

if ("$head" != "") then
    $b $options -h "$head" $files >>$basename.tex
else
    $b $options $files >>$basename.tex
endif

# Change to directory containing output files, so temporary index
# files go there.  If no directory path was given, $basename:h is
# identical to $basename, instead of the more logical empty string.
if ("$basename" != "$basename:h") cd $basename:h

$nawk -f $lib/tgrindex.awk <$basename.tex >$basename.tmp
/bin/mv $basename.tmp $basename.tex

if ("$format" == "Y") then
    cat $basename.tex
    /bin/rm -f $basename.tex
    goto done
endif

echo "TeXing..."
$tex $texoptions $basename.tex

# PUT OUTPUT HANDLING COMMANDS HERE.

if ( -f $basename.dvi ) then
    echo "Creating PostScript output..."
# Choose ONE DVI driver here:
    dvialw -q -outfile=$basename.ps $basename.dvi
#   dvips -o $basename.ps $basename.dvi
endif

ls -l $basename.*

if ("$print" == "Y") then
    echo "Printing..."
    # Solaris 2.x uses lp, many other UNIX variants use lpr
    if ( -x /usr/5bin/lp ) then
	set LPR=/usr/5bin/lp
    else
	set LPR=lpr
    endif
    $LPR $basename.ps
endif

done:
